<?php

/**
 * @file
 * Example form for the radios_select module.
 */

/**
 * Displays an example form.
 */
function radios_select_example_form($form, &$form_state) {

  $form['#tree'] = TRUE;

  $form['rs_example_header'] = array(
    '#type'          => 'markup',
    '#markup'        => '<h2>' . t('Radios Select attributes and examples') . '</h2>',
  );

  $form['rs_example'] = array(
    '#type'          => 'fieldset',
    '#title'         => t('Full list of radios select properties'),
    '#collapsible'   => TRUE,
    '#collapsed'     => TRUE,
  );

  /* LIST OF ATTRIBUTES */

  $header = array(
    array('data' => t('Property'), 'colspan' => 2),
    t('Description'),
    t('Possible values'),
    t('Default value'),
    t('Notes'),
  );

  $rows[] = array(
    array('data' => '<b>#radios_select</b>', 'colspan' => 2),
    t('This enables Radios Select for the current radios form element.'),
    'TRUE, FALSE',
    t('none (FALSE)'),
    '',
  );

  $rows[] = array(array('data' => '<b>#rs_attributes[element]</b>', 'colspan' => 6));

  $rows[] = array(
    '',
    'frame_color',
    t('Sets color of the radios select frame.'),
    t('CSS value, color (for example: #339933)'),
    '#333333',
    '',
  );
  $rows[] = array(
    '',
    'hollow',
    t('Displays only frame border and merges selector and current item.'),
    'TRUE, FALSE',
    'FALSE',
    t('Used color of frame (if set) specified in <i>frame_color</i> or else #333333 by default.'),
  );
  $rows[] = array(
    '',
    'dark_arrow',
    t('Sets dark arrow image (at right of element). By default element uses white arrow.'),
    'TRUE, FALSE',
    'FALSE',
    '',
  );
  $rows[] = array(
    '',
    'columns',
    t('Aligns labels in selector to specified number of columns.'),
    t('unsigned number <br />(any > 0)'),
    '1',
    t('This will ignore the <i>width</i> property of labels (if it set).'),
  );
  $rows[] = array(
    '',
    'css',
    t('Attaching custom stylesheet to the current radios select'),
    t('array() of usual CSS definitions, where each entry should be one separate class definition.'),
    t('none'),
    t('<b>Note:</b> definitions are automatically wrapped by .form-item-{name-of-element} class, so use only nested selectors.<br /><b>Note:</b> there is not allowed to defining multiple classes in one array\'s index (see example 7).'),
  );

  $rows[] = array(array('data' => '<b>#rs_attributes[label]</b>', 'colspan' => 6));

  $rows[] = array(
    '',
    'font',
    t('Sets font family name for text in labels.'),
    t('CSS-value (string).'),
    t('none <br />(used Drupal CSS value for radios)'),
    '',
  );
  $rows[] = array(
    '',
    'font_size',
    t('Sets font size of text in labels.'),
    t('CSS value (number).'),
    '18px',
    t('Used <i>units</i> property if set (or "px" by default).'),
  );
  $rows[] = array(
    '',
    'font_color',
    t('Sets font color of text in labels.'),
    t('CSS value (color).'),
    t('none <br />(used Drupal CSS value for radios)'),
    '',
  );
  $rows[] = array(
    '',
    'line_height',
    t('Sets line height of text in labels.'),
    t('CSS value (number).'),
    '2em',
    t('Used <i>units</i> property if set (or "px" by default).'),
  );
  $rows[] = array(
    '',
    'width',
    t('Sets width of labels.'),
    t('CSS value (number).'),
    t('none'),
    t('Used <i>units</i> property if set (or "px" by default).'),
  );
  $rows[] = array(
    '',
    'height',
    t('Sets height of labels.'),
    t('CSS value (number).'),
    t('none'),
    t('Used <i>units</i> property if set (or "px" by default).'),
  );
  $rows[] = array(
    '',
    'padding_x',
    t('Sets horizontal padding of labels.'),
    t('CSS value (number).'),
    '5px',
    t('Used <i>units</i> property if set (or "px" by default).'),
  );
  $rows[] = array(
    '',
    'padding_y',
    t('Sets vertical padding of labels.'),
    t('CSS value (number).'),
    '0',
    t('Used <i>units</i> property if set (or "px" by default).'),
  );
  $rows[] = array(
    '',
    'valign',
    t('Sets vertical alignment of labels in selector container.'),
    t('CSS values: top, bottom, baseline, etc... or numeric offset (if number)'),
    'top',
    t('Used <i>units</i> property if set (or "px" by default).'),
  );
  $rows[] = array(
    '',
    'img_valign',
    t('Sets vertical alignment of images in labels (if exist any).'),
    t('CSS values: top, bottom, baseline, etc... or numeric offset (if number)'),
    t('none'),
    t('Used <i>units</i> property if set (or "px" by default).') . t('<br />Most of browsers uses <i>"baseline"</i> value by default for images.'),
  );
  $rows[] = array(
    '',
    'nowrap',
    t('Sets nowrap CSS-property to text in labels.'),
    'TRUE, FALSE',
    'FALSE',
    '',
  );
  $rows[] = array(
    '',
    'units',
    t('Sets units used in label properties (if not set within CSS value)'),
    'px, em',
    'px',
    '',
  );

  $form['rs_example']['table'] = array(
    '#type'          => 'markup',
    '#markup'        => theme('table', array('header' => $header, 'rows' => $rows)),
  );

  /* EXAMPLE 1 */

  $form['rs_example_1'] = array(
    '#type'          => 'fieldset',
    '#title'         => t('Example 1. Simple radios select'),
    '#collapsible'   => TRUE,
    '#collapsed'     => TRUE,
    '#description'   => t('Just simple radios select without any attributes.'),
  );

  $values = preg_split('/[\s,\.]+/', ucwords('Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Maecenas sodales congue velit. Duis commodo interdum ipsum.'));

  $form['rs_example_1']['radios_select_1'] = array(
    '#type'          => 'radios',
    '#title'         => t('Select word:'),
    '#default_value' => 1,
    '#options'       => $values,
    '#radios_select' => TRUE,
    '#description'   => t('Word to use in form.'),
  );

  $form['rs_example_1']['code'] = array(
    '#type'          => 'fieldset',
    '#title'         => t('Code'),
    '#collapsible'   => TRUE,
    '#collapsed'     => TRUE,
  );

  $form['rs_example_1']['code']['markup'] = array(
    '#type'          => 'markup',
    '#markup'        => t('
<pre>
$values = preg_split(\'/[\s,\.]+/\', ucwords(\'Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Maecenas sodales congue velit. Duis commodo interdum ipsum.\'));

$form[\'rs_example_1\'][\'radios_select_1\'] = array(
  \'#type\'          => \'radios\',
  \'#title\'         => t(\'Select word:\'),
  \'#default_value\' => 1,
  \'#options\'       => $values,
  \'#radios_select\' => TRUE,     // enables Radios Select for this radios element
  \'#description\'   => t(\'Word to use in form.\'),
);
</pre>'),
  );

  /* EXAMPLE 2 */

  $form['rs_example_2'] = array(
    '#type'          => 'fieldset',
    '#title'         => t('Example 2. Font settings: font, color, size and line height.'),
    '#collapsible'   => TRUE,
    '#collapsed'     => TRUE,
    '#description'   => t('Radios select with custom font properties.'),
  );

  $form['rs_example_2']['radios_select_2'] = array(
    '#type'          => 'radios',
    '#title'         => t('Select word:'),
    '#default_value' => 2,
    '#options'       => $values,
    '#radios_select' => TRUE,
    '#rs_attributes' => array(
      'label'         => array(
        'font'         => 'Times New Roman',
        'font_size'    => 1.4,
        'font_color'   => '#339933',
        'line_height'  => 2,
        'units'        => 'em',
      ),
    ),
    '#description'   => t('Word to use in form.'),
  );

  $form['rs_example_2']['code'] = array(
    '#type'          => 'fieldset',
    '#title'         => t('Code'),
    '#collapsible'   => TRUE,
    '#collapsed'     => TRUE,
  );

  $form['rs_example_2']['code']['markup'] = array(
    '#type'          => 'markup',
    '#markup'        => t('
<pre>
$values = preg_split(\'/[\s,\.]+/\', ucwords(\'Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Maecenas sodales congue velit. Duis commodo interdum ipsum.\'));

$form[\'rs_example_2\'][\'radios_select_2\'] = array(
  \'#type\'          => \'radios\',
  \'#title\'         => t(\'Select word:\'),
  \'#default_value\' => 2,
  \'#options\'       => $values,
  \'#radios_select\' => TRUE,     // enables Radios Select for this radios element
  \'#rs_attributes\' => array(
    \'label\'         => array(
      \'font\'         => \'Times New Roman\',  // this sets font family (same as in CSS way)
      \'font_size\'    => 1.4,              // this sets font size (in "units" units)
      \'font_color\'   => \'#339933\',        // this sets font color (same as in CSS way)
      \'line_height\'  => 2,                // this sets line height (in "units" units)
      \'units\'        => \'em\',             // can be em or px (default: px)
    ),
  ),
  \'#description\'   => t(\'Word to use in form.\'),
);
</pre>'),
  );

  /* EXAMPLE 3 */

  $form['rs_example_3'] = array(
    '#type'          => 'fieldset',
    '#title'         => t('Example 3. Fixed width and height. Setting padding.'),
    '#collapsible'   => TRUE,
    '#collapsed'     => TRUE,
    '#description'   => t('Radios select with fixed width and height.<br />(Useful for output tables of characters, images, etc...)'),
  );

  $values = array();
  for ($i = 33; $i < 256; $i++) {
    $values[] = '&#' . $i . ';';
  }
  $values = array_combine($values, $values);

  // Replace Soft Hyphen symbol (&#173;) by non-breaking space
  // (this symbol produces row break in Firefox and Opera)
  $values['&#173;'] = '&nbsp;';

  $form['rs_example_3']['radios_select_3'] = array(
    '#type'          => 'radios',
    '#title'         => t('Select symbol:'),
    '#default_value' => '&#169;',
    '#options'       => $values,
    '#radios_select' => TRUE,
    '#rs_attributes' => array(
      'label'         => array(
        'width'        => 2,
        'height'       => 2,
        'line_height'  => 2,
        'padding_x'    => '3px',
        'padding_y'    => '3px',
        'units'        => 'em',
      ),
    ),
    '#description'   => t('Symbol to use in form.'),
  );

  $form['rs_example_3']['code'] = array(
    '#type'          => 'fieldset',
    '#title'         => t('Code'),
    '#collapsible'   => TRUE,
    '#collapsed'     => TRUE,
  );

  $form['rs_example_3']['code']['markup'] = array(
    '#type'          => 'markup',
    '#markup'        => t('
<pre>
$values = array();
for ($i = 33; $i < 256; $i++) {
  $values[] = \'&#\' . $i . \';\';
}
$values = array_combine($values, $values);

// Replace Soft Hyphen symbol (&amp;#173;) by non-breaking space
// (this symbol produces row break in Firefox and Opera)
$values[\'&amp;#173;\'] = \'&amp;nbsp;\';

$form[\'rs_example_3\'][\'radios_select_3\'] = array(
  \'#type\'          => \'radios\',
  \'#title\'         => t(\'Select symbol:\'),
  \'#default_value\' => \'&amp;#169;\',
  \'#options\'       => $values,
  \'#radios_select\' => TRUE,     // enables Radios Select for this radios element
  \'#rs_attributes\' => array(
    \'label\'          => array(
      \'width\'          => 2,      // sets label width (in "units" units)
      \'height\'         => 2,      // sets label height (in "units" units)
      \'line_height\'    => 2,
      \'padding_x\'      => \'3px\',  // horizontal padding (we use px instead of units)
      \'padding_y\'      => \'3px\',  // vertical padding (we use px instead of units)
      \'units\'          => \'em\',
    ),
  ),
  \'#description\'   => t(\'Symbol to use in form.\'),
);
</pre>'),
  );

  /* EXAMPLE 4 */

  $form['rs_example_4'] = array(
    '#type'          => 'fieldset',
    '#title'         => t('Example 4. Frame coloring and dark arrow. Setting hollow mode.'),
    '#collapsible'   => TRUE,
    '#collapsed'     => TRUE,
    '#description'   => t('Radios select with customized frame color.'),
  );

  $values = array_merge(range('A', 'Z'), range('a', 'z'));

  $form['rs_example_4']['radios_select_4_1'] = array(
    '#type'          => 'radios',
    '#title'         => t('Select character:'),
    '#default_value' => 2,
    '#options'       => $values,
    '#radios_select' => TRUE,
    '#rs_attributes' => array(
      'element'       => array(
        'frame_color'  => '#d4d0c8',
        'dark_arrow'   => TRUE,
      ),
      'label'         => array(
        'width'        => 2,
        'height'       => 2,
        'padding_x'    => '3px',
        'padding_y'    => '3px',
        'units'        => 'em',
      ),
    ),
    '#description'   => t('Character to use in form.'),
  );

  $form['rs_example_4']['code_1'] = array(
    '#type'          => 'fieldset',
    '#title'         => t('Code'),
    '#collapsible'   => TRUE,
    '#collapsed'     => TRUE,
  );

  $form['rs_example_4']['code_1']['markup'] = array(
    '#type'          => 'markup',
    '#markup'        => t('
<pre>
$values = array_merge(range(\'A\', \'Z\'), range(\'a\', \'z\'));

$form[\'rs_example_4\'][\'radios_select_4_1\'] = array(
  \'#type\'          => \'radios\',
  \'#title\'         => t(\'Select character:\'),
  \'#default_value\' => 2,
  \'#options\'       => $values,
  \'#radios_select\' => TRUE,     // enables Radios Select for this radios element
  \'#rs_attributes\' => array(
    \'element\'        => array(
      \'frame_color\'    => \'#d4d0c8\', // this sets frame color
      \'dark_arrow\'     => TRUE,      // this sets dark arrow for this element
     ),
    \'label\'          => array(
      \'width\'          => 2,
      \'height\'         => 2,
      \'padding_x\'      => \'3px\',
      \'padding_y\'      => \'3px\',
      \'units\'          => \'em\',
     ),
   ),
  \'#description\'   => t(\'Character to use in form.\'),
);
</pre>'),
  );

  $form['rs_example_4']['info_1'] = array(
    '#type'          => 'markup',
    '#markup'        => t('<p>Radios select with hollow frame.</p>'),
  );

  $form['rs_example_4']['radios_select_4_2'] = array(
    '#type'          => 'radios',
    '#title'         => t('Select character:'),
    '#default_value' => 2,
    '#options'       => $values,
    '#radios_select' => TRUE,
    '#rs_attributes' => array(
      'element'       => array(
        'hollow'       => TRUE,
      ),
      'label'         => array(
        'width'        => 2,
        'height'       => 2,
        'padding_x'    => '3px',
        'padding_y'    => '3px',
        'units'        => 'em',
      ),
    ),
    '#description'   => t('Character to use in form.'),
  );

  $form['rs_example_4']['code_2'] = array(
    '#type'          => 'fieldset',
    '#title'         => t('Code'),
    '#collapsible'   => TRUE,
    '#collapsed'     => TRUE,
  );

  $form['rs_example_4']['code_2']['markup'] = array(
    '#type'          => 'markup',
    '#markup'        => t('
<pre>
$values = array_merge(range(\'A\', \'Z\'), range(\'a\', \'z\'));

$form[\'rs_example_4\'][\'radios_select_4_2\'] = array(
  \'#type\'          => \'radios\',
  \'#title\'         => t(\'Select character:\'),
  \'#default_value\' => 2,
  \'#options\'       => $values,
  \'#radios_select\' => TRUE,     // enables Radios Select for this radios element
  \'#rs_attributes\' => array(
    \'element\'         => array(
      \'hollow\'          => TRUE,   // this sets hollow mode
     ),
    \'label\'         => array(
      \'width\'           => 2,
      \'height\'          => 2,
      \'padding_x\'       => \'3px\',
      \'padding_y\'       => \'3px\',
      \'units\'           => \'em\',
     ),
   ),
  \'#description\'   => t(\'Character to use in form.\'),
);
</pre>'),
  );

  /* EXAMPLE 5 */

  $form['rs_example_5'] = array(
    '#type'          => 'fieldset',
    '#title'         => t('Example 5. Images in labels and vertical alignment. Nowrap option.'),
    '#collapsible'   => TRUE,
    '#collapsed'     => TRUE,
    '#description'   => t('Radios select with vertical alignment of labels (1) and vertical alignment of images inside them (2).'),
  );

  $form['rs_example_5']['info_1'] = array(
    '#type'          => 'markup',
    '#markup'        => t('<p>1. Example how to insert images to labels. Also in some cases you need to align labels in the rows to the bottom line. This example explains how to make this.</p>'),
  );

  $module_path = url(drupal_get_path('module', 'radios_select'));
  $images_path = $module_path . '/examples/images/';

  $values = array(
    '<img src="' . $images_path . 'image1.png" /><br />Some image 1',
    '<img src="' . $images_path . 'image2.png" /><br />Some image 2',
    '<img src="' . $images_path . 'image3.png" /><br />Some image 3',
    '<img src="' . $images_path . 'image1.png" /><br />Some image 4',
    '<img src="' . $images_path . 'image2.png" /><br />Some image 5',
    '<img src="' . $images_path . 'image3.png" /><br />Some image 6',
  );

  $form['rs_example_5']['radios_select_5_1'] = array(
    '#type'          => 'radios',
    '#title'         => t('Select image:'),
    '#default_value' => 0,
    '#options'       => $values,
    '#radios_select' => TRUE,
    '#rs_attributes' => array(
      'label'         => array(
        'valign'        => 'bottom',
        'font_size'     => 12,
        'line_height'   => 14,
        'padding_x'     => 4,
        'padding_y'     => 4,
      ),
    ),
    '#description'   => t('Select horizontal or vertical image.'),
  );

  $form['rs_example_5']['code_1'] = array(
    '#type'          => 'fieldset',
    '#title'         => t('Code'),
    '#collapsible'   => TRUE,
    '#collapsed'     => TRUE,
  );

  $form['rs_example_5']['code_1']['markup'] = array(
    '#type'          => 'markup',
    '#markup'        => t('
<pre>
$module_path = url(drupal_get_path(\'module\', \'radios_select\'));
$images_path = $module_path . \'/examples/images/\';

$values = array(
  \'&#60;img src="\' . $images_path . \'image1.png" /&#62;&#60;br /&#62;Some image 1\',
  \'&#60;img src="\' . $images_path . \'image2.png" /&#62;&#60;br /&#62;Some image 2\',
  \'&#60;img src="\' . $images_path . \'image3.png" /&#62;&#60;br /&#62;Some image 3\',
  \'&#60;img src="\' . $images_path . \'image1.png" /&#62;&#60;br /&#62;Some image 4\',
  \'&#60;img src="\' . $images_path . \'image2.png" /&#62;&#60;br /&#62;Some image 5\',
  \'&#60;img src="\' . $images_path . \'image3.png" /&#62;&#60;br /&#62;Some image 6\',
);

$form[\'rs_example_5\'][\'radios_select_5_1\'] = array(
  \'#type\'          => \'radios\',
  \'#title\'         => t(\'Select image:\'),
  \'#default_value\' => 0,
  \'#options\'       => $values,
  \'#radios_select\' => TRUE,     // enables Radios Select for this radios element
  \'#rs_attributes\' => array(
    \'label\'         => array(
      \'valign\'        => \'bottom\', // this sets vertical alignment of labels to bottom
      \'font_size\'     => 12,
      \'line_height\'   => 14,
      \'padding_x\'     => 4,
      \'padding_y\'     => 4,
     ),
   ),
  \'#description\'   => t(\'Select horizontal or vertical image.\'),
);
</pre>'),
  );

  $form['rs_example_5']['info_2'] = array(
    '#type'          => 'markup',
    '#markup'        => t('<p>2. Example how to set vertical alignment of images in labels and disable word wrap . In some cases you need to specify images alignment regarding baseline. This example explains how to make this.</p>'),
  );

  $values = array(
    '<img src="' . $images_path . 'ru.png" /> Russian Federation',
    '<img src="' . $images_path . 'us.png" /> USA',
    '<img src="' . $images_path . 'ca.png" /> Canada',
    '<img src="' . $images_path . 'fr.png" /> France',
    '<img src="' . $images_path . 'de.png" /> Germany',
    '<img src="' . $images_path . 'it.png" /> Italy',
    '<img src="' . $images_path . 'gb.png" /> United Kingdom',
    '<img src="' . $images_path . 'gr.png" /> Greece',
    '<img src="' . $images_path . 'tr.png" /> Turkey',
    '<img src="' . $images_path . 'ua.png" /> Ukraine',
    '<img src="' . $images_path . 'es.png" /> Spain',
    '<img src="' . $images_path . 'no.png" /> Norway',
  );

  $form['rs_example_5']['radios_select_5_2'] = array(
    '#type'          => 'radios',
    '#title'         => t('Select country:'),
    '#default_value' => 0,
    '#options'       => $values,
    '#radios_select' => TRUE,
    '#rs_attributes' => array(
      'label'         => array(
        'img_valign'   => '-4px',
        'nowrap'       => TRUE,
      ),
    ),
    '#description'   => t('Country from where you are.'),
  );

  $form['rs_example_5']['code_2'] = array(
    '#type'          => 'fieldset',
    '#title'         => t('Code'),
    '#collapsible'   => TRUE,
    '#collapsed'     => TRUE,
  );

  $form['rs_example_5']['code_2']['markup'] = array(
    '#type'          => 'markup',
    '#markup'        => t('
<pre>
$module_path = url(drupal_get_path(\'module\', \'radios_select\'));
$images_path = $module_path . \'/examples/images/\';

$values = array(
  \'&#60;img src="\' . $images_path . \'ru.png" /&#62; Russian Federation\',
  \'&#60;img src="\' . $images_path . \'us.png" /&#62; USA\',
  \'&#60;img src="\' . $images_path . \'ca.png" /&#62; Canada\',
  \'&#60;img src="\' . $images_path . \'fr.png" /&#62; France\',
  \'&#60;img src="\' . $images_path . \'de.png" /&#62; Germany\',
  \'&#60;img src="\' . $images_path . \'it.png" /&#62; Italy\',
  \'&#60;img src="\' . $images_path . \'gb.png" /&#62; United Kingdom\',
  \'&#60;img src="\' . $images_path . \'gr.png" /&#62; Greece\',
  \'&#60;img src="\' . $images_path . \'tr.png" /&#62; Turkey\',
  \'&#60;img src="\' . $images_path . \'ua.png" /&#62; Ukraine\',
  \'&#60;img src="\' . $images_path . \'no.png" /&#62; Norway\',
);

$form[\'rs_example_5\'][\'radios_select_5_2\'] = array(
  \'#type\'          => \'radios\',
  \'#title\'         => t(\'Select country:\'),
  \'#default_value\' => 0,
  \'#options\'       => $values,
  \'#radios_select\' => TRUE,     // enables Radios Select for this radios element
  \'#rs_attributes\' => array(
    \'label\'         => array(
      \'img_valign\'    => \'-4px\',        // sets vertical alignment of images
      \'nowrap\'        => \'TRUE\',        // disables word wrapping for text in labels
     ),
   ),
  \'#description\'   => t(\'Country from where you are.\'),
);
</pre>'),
  );

  /* EXAMPLE 6 */

  $form['rs_example_6'] = array(
    '#type'          => 'fieldset',
    '#title'         => t('Example 6. Columns.'),
    '#collapsible'   => TRUE,
    '#collapsed'     => TRUE,
    '#description'   => t('Example how to set labels to the specified number of columns.<br /><b>Note:</b> this does not works well for IE browsers, so full width of selector for IE automatically sets to 99%.'),
  );

  $form['rs_example_6']['radios_select_6'] = array(
    '#type'          => 'radios',
    '#title'         => t('Select country:'),
    '#default_value' => 0,
    '#options'       => $values,
    '#radios_select' => TRUE,
    '#rs_attributes' => array(
      'element'         => array(
        'columns'         => 4,
      ),
      'label'         => array(
        'img_valign'      => -4,
        'nowrap'          => TRUE,
      ),
    ),
    '#description'   => t('Country from where you are.'),
  );

  $form['rs_example_6']['code'] = array(
    '#type'          => 'fieldset',
    '#title'         => t('Code'),
    '#collapsible'   => TRUE,
    '#collapsed'     => TRUE,
  );

  $form['rs_example_6']['code']['markup'] = array(
    '#type'          => 'markup',
    '#markup'        => t('
<pre>
$module_path = url(drupal_get_path(\'module\', \'radios_select\'));
$images_path = $module_path . \'/examples/images/\';

$values = array(
  \'&#60;img src="\' . $images_path . \'ru.png" /&#62; Russian Federation\',
  \'&#60;img src="\' . $images_path . \'us.png" /&#62; USA\',
  \'&#60;img src="\' . $images_path . \'ca.png" /&#62; Canada\',
  \'&#60;img src="\' . $images_path . \'fr.png" /&#62; France\',
  \'&#60;img src="\' . $images_path . \'de.png" /&#62; Germany\',
  \'&#60;img src="\' . $images_path . \'it.png" /&#62; Italy\',
  \'&#60;img src="\' . $images_path . \'gb.png" /&#62; United Kingdom\',
  \'&#60;img src="\' . $images_path . \'gr.png" /&#62; Greece\',
  \'&#60;img src="\' . $images_path . \'tr.png" /&#62; Turkey\',
  \'&#60;img src="\' . $images_path . \'ua.png" /&#62; Ukraine\',
  \'&#60;img src="\' . $images_path . \'no.png" /&#62; Norway\',
);

$form[\'rs_example_6\'][\'radios_select_6\'] = array(
  \'#type\'          => \'radios\',
  \'#title\'         => t(\'Select country:\'),
  \'#default_value\' => 0,
  \'#options\'       => $values,
  \'#radios_select\' => TRUE,     // enables Radios Select for this radios element
  \'#rs_attributes\' => array(
    \'element\'         => array(
      \'columns\'         => 4,       // this sets ordering by 4 columns
    ),
    \'label\'         => array(
      \'img_valign\'      => -4,      // px by default, so we can skip units
      \'nowrap\'          => \'TRUE\',
     ),
   ),
  \'#description\'   => t(\'Country from where you are.\'),
);
</pre>'),
  );

  /* EXAMPLE 7 */

  $form['rs_example_7'] = array(
    '#type'          => 'fieldset',
    '#title'         => t('Example 7. Custom CSS.'),
    '#collapsible'   => TRUE,
    '#collapsed'     => TRUE,
    '#description'   => t('Example how to attach custom CSS to the current Radios Select.<br /><b>Note:</b>Custom CSS will be attached after all other styles produced by Radios Select module.'),
  );

  $form['rs_example_7']['radios_select_7'] = array(
    '#type'          => 'radios',
    '#title'         => t('Select country:'),
    '#default_value' => 0,
    '#options'       => $values,
    '#radios_select' => TRUE,
    '#rs_attributes' => array(
      'element'         => array(
        'columns'         => 4,
        'css'             => array(
          'div.type-radios-current {background: #222 url("' . $images_path . 'custom_bg.png") bottom right no-repeat; border-color: #222 !important;}',
          'div.type-radios-current .inner {background: #a8a8a8;}',
          'div.type-radios-current label  {background: #ffc136 url("' . $images_path . 'custom_label_active.png") center center repeat-x !important; border: 1px solid #c35e22 !important; color: black;}',
          'div.rs_opened {background: #222 url("' . $images_path . 'custom_bg_active.png") bottom right no-repeat;}',
          'div.rs_opened .inner {background: none;}',
          'div.type-radios-select {background: #e8e8e8 url("' . $images_path . 'custom_select_bg.png") top center repeat-x !important; border-color: #222 !important;}',
          'div.type-radios-select label.selected {background: #ffc136 url("' . $images_path . 'custom_label_active.png") center center repeat-x !important; border: 1px solid #c35e22 !important; color: black;}',
          'div.type-radios-select label {background: #484848 url("' . $images_path . 'custom_label.png") center center repeat-x !important; border: 1px solid #222 !important; color: white;}',
          'div.type-radios-select label:hover {background: #ffc136 url("' . $images_path . 'custom_label_active.png") center center repeat-x !important;}',
        ),
      ),
      'label'         => array(
        'img_valign'      => -4,
        'nowrap'          => TRUE,
      ),
    ),
    '#description'   => t('Country from where you are.'),
  );

  $form['rs_example_7']['code'] = array(
    '#type'          => 'fieldset',
    '#title'         => t('Code'),
    '#collapsible'   => TRUE,
    '#collapsed'     => TRUE,
  );

  $form['rs_example_7']['code']['markup'] = array(
    '#type'          => 'markup',
    '#markup'        => t('
<pre>
$module_path = url(drupal_get_path(\'module\', \'radios_select\'));
$images_path = $module_path . \'/examples/images/\';

$values = array(
  \'&#60;img src="\' . $images_path . \'ru.png" /&#62; Russian Federation\',
  \'&#60;img src="\' . $images_path . \'us.png" /&#62; USA\',
  \'&#60;img src="\' . $images_path . \'ca.png" /&#62; Canada\',
  \'&#60;img src="\' . $images_path . \'fr.png" /&#62; France\',
  \'&#60;img src="\' . $images_path . \'de.png" /&#62; Germany\',
  \'&#60;img src="\' . $images_path . \'it.png" /&#62; Italy\',
  \'&#60;img src="\' . $images_path . \'gb.png" /&#62; United Kingdom\',
  \'&#60;img src="\' . $images_path . \'gr.png" /&#62; Greece\',
  \'&#60;img src="\' . $images_path . \'tr.png" /&#62; Turkey\',
  \'&#60;img src="\' . $images_path . \'ua.png" /&#62; Ukraine\',
  \'&#60;img src="\' . $images_path . \'no.png" /&#62; Norway\',
);

$form[\'rs_example_7\'][\'radios_select_7\'] = array(
  \'#type\'          => \'radios\',
  \'#title\'         => t(\'Select country:\'),
  \'#default_value\' => 0,
  \'#options\'       => $values,
  \'#radios_select\' => TRUE,     // enables Radios Select for this radios element
  \'#rs_attributes\' => array(
    \'element\'         => array(
      \'columns\'         => 4,
      \'css\'             => array(
        \'div.type-radios-current {background: #222 url("\'. $images_path . \'custom_bg.png") bottom right no-repeat; border-color: #222 !important;}\',
        \'div.type-radios-current .inner {background: #a8a8a8;}\',
        \'div.type-radios-current label  {background: #ffc136 url("\'. $images_path . \'custom_label_active.png") center center repeat-x !important; border: 1px solid #c35e22 !important; color: black;}\',
        \'div.rs_opened {background: #222 url("\'. $images_path . \'custom_bg_active.png") bottom right no-repeat;}\',
        \'div.rs_opened .inner {background: none;}\',
        \'div.type-radios-select {background: #d0d0d0 url("\'. $images_path . \'custom_select_bg.png") top center repeat-x !important; border-color: #222 !important;}\',
        \'div.type-radios-select label.selected {background: #ffc136 url("\'. $images_path . \'custom_label_active.png") center center repeat-x !important; border: 1px solid #c35e22 !important; color: black;}\',
        \'div.type-radios-select label {background: #3a3a3a url("\'. $images_path . \'custom_label.png") center center repeat-x !important; border: 1px solid #222 !important; color: white;}\',
        \'div.type-radios-select label:hover {background: #ffc136 url("\'. $images_path . \'custom_label_active.png") center center repeat-x !important;}\',
      ),
    ),
    \'label\'         => array(
      \'img_valign\'      => -4,
      \'nowrap\'          => \'TRUE\',
     ),
   ),
  \'#description\'   => t(\'Country from where you are.\'),
);
</pre>'),
  );

  $form['buttons']['submit'] = array(
    '#type'          => 'submit',
    '#value'         => t('View submitted values'),
  );

  return $form;
}

/**
 * Form submission handler for radios_select_example_form().
 */
function radios_select_example_form_submit($form, &$form_state) {
  drupal_set_message(t('Submitted values:') .
    '<br />$form_state[\'values\'][\'rs_example_1\'][\'radios_select_1\']: ' . $form_state['values']['rs_example_1']['radios_select_1'] .
    '<br />$form_state[\'values\'][\'rs_example_2\'][\'radios_select_2\']: ' . $form_state['values']['rs_example_2']['radios_select_2'] .
    '<br />$form_state[\'values\'][\'rs_example_3\'][\'radios_select_3\']: ' . $form_state['values']['rs_example_3']['radios_select_3'] .
    '<br />$form_state[\'values\'][\'rs_example_4\'][\'radios_select_4_1\']: ' . $form_state['values']['rs_example_4']['radios_select_4_1'] .
    '<br />$form_state[\'values\'][\'rs_example_4\'][\'radios_select_4_2\']: ' . $form_state['values']['rs_example_4']['radios_select_4_2'] .
    '<br />$form_state[\'values\'][\'rs_example_5\'][\'radios_select_5_1\']: ' . $form_state['values']['rs_example_5']['radios_select_5_1'] .
    '<br />$form_state[\'values\'][\'rs_example_5\'][\'radios_select_5_2\']: ' . $form_state['values']['rs_example_5']['radios_select_5_2'] .
    '<br />$form_state[\'values\'][\'rs_example_6\'][\'radios_select_6\']: ' . $form_state['values']['rs_example_6']['radios_select_6'] .
    '<br />$form_state[\'values\'][\'rs_example_7\'][\'radios_select_7\']: ' . $form_state['values']['rs_example_7']['radios_select_7']);
}
